summaryrefslogtreecommitdiff
path: root/gr-channels/lib/fading_model_impl.cc
diff options
context:
space:
mode:
authorTom Rondeau <trondeau@vt.edu>2013-03-08 10:01:37 -0500
committerTom Rondeau <trondeau@vt.edu>2013-03-08 10:01:37 -0500
commitfe70fa72ea22a133874337da2d03d30611e5ab1c (patch)
tree720a9e4e289e9a029fb363c635675daf91e5f77b /gr-channels/lib/fading_model_impl.cc
parent0970c7eaa165c6dc7d70be55dbf3d272b88fc109 (diff)
blocks: removed all nco/vco and fxpt stuff from core; now in gr-blocks.
Moved the nco/vco tests to gr-blocks/test and enabled them.
Diffstat (limited to 'gr-channels/lib/fading_model_impl.cc')
-rw-r--r--gr-channels/lib/fading_model_impl.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/gr-channels/lib/fading_model_impl.cc b/gr-channels/lib/fading_model_impl.cc
index 080a3b8e06..b38ff82892 100644
--- a/gr-channels/lib/fading_model_impl.cc
+++ b/gr-channels/lib/fading_model_impl.cc
@@ -27,11 +27,11 @@
#include <boost/format.hpp>
#include <boost/random.hpp>
-#include <gr_fxpt.h>
+#include <blocks/fxpt.h>
#include <sincostable.h>
// FASTSINCOS: 0 = slow native, 1 = gr_fxpt impl, 2 = sincostable.h
#define FASTSINCOS 2
@@ -178,8 +178,8 @@ namespace gr {
for(int n=1; n<d_N; n++){
float alpha_n = (2*M_PI*n - M_PI + d_theta)/4*d_N;
#if FASTSINCOS == 1
- float s_i = scale_sin*gr_fxpt::cos(gr_fxpt::float_to_fixed(2*M_PI*d_fDTs*d_m*gr_fxpt::cos(gr_fxpt::float_to_fixed(alpha_n))+d_psi[n+1]));
- float s_q = scale_sin*gr_fxpt::cos(gr_fxpt::float_to_fixed(2*M_PI*d_fDTs*d_m*gr_fxpt::sin(gr_fxpt::float_to_fixed(alpha_n))+d_phi[n+1]));
+ float s_i = scale_sin*gr::blocks::fxpt::cos(gr::blocks::fxpt::float_to_fixed(2*M_PI*d_fDTs*d_m*gr::blocks::fxpt::cos(gr::blocks::fxpt::float_to_fixed(alpha_n))+d_psi[n+1]));
+ float s_q = scale_sin*gr::blocks::fxpt::cos(gr::blocks::fxpt::float_to_fixed(2*M_PI*d_fDTs*d_m*gr::blocks::fxpt::sin(gr::blocks::fxpt::float_to_fixed(alpha_n))+d_phi[n+1]));
#elif FASTSINCOS == 2
float s_i = scale_sin*d_table.cos(2*M_PI*d_fDTs*d_m*d_table.cos(alpha_n)+d_psi[n+1]);
float s_q = scale_sin*d_table.cos(2*M_PI*d_fDTs*d_m*d_table.sin(alpha_n)+d_phi[n+1]);
@@ -194,8 +194,8 @@ namespace gr {
if(d_LOS){
#if FASTSINCOS == 1
- float los_i = gr_fxpt::cos(gr_fxpt::float_to_fixed(2*M_PI*d_fDTs*d_m*gr_fxpt::cos(gr_fxpt::float_to_fixed(d_theta_los)) + d_psi[0]));
- float los_q = gr_fxpt::sin(gr_fxpt::float_to_fixed(2*M_PI*d_fDTs*d_m*gr_fxpt::cos(gr_fxpt::float_to_fixed(d_theta_los)) + d_psi[0]));
+ float los_i = gr::blocks::fxpt::cos(gr::blocks::fxpt::float_to_fixed(2*M_PI*d_fDTs*d_m*gr::blocks::fxpt::cos(gr::blocks::fxpt::float_to_fixed(d_theta_los)) + d_psi[0]));
+ float los_q = gr::blocks::fxpt::sin(gr::blocks::fxpt::float_to_fixed(2*M_PI*d_fDTs*d_m*gr::blocks::fxpt::cos(gr::blocks::fxpt::float_to_fixed(d_theta_los)) + d_psi[0]));
#elif FASTSINCOS == 2
float los_i = d_table.cos(2*M_PI*d_fDTs*d_m*d_table.cos(d_theta_los) + d_psi[0]);
float los_q = d_table.sin(2*M_PI*d_fDTs*d_m*d_table.cos(d_theta_los) + d_psi[0]);
@@ -27,11 +27,11 @@
#include <sincostable.h>
-// FASTSINCOS: 0 = slow native, 1 = gr_fxpt impl, 2 = sincostable.h
+// FASTSINCOS: 0 = slow native, 1 = gr::blocks::fxpt impl, 2 = sincostable.h
#define FASTSINCOS 2